#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 th-orphans
version:              0.13.17
visibility:           public
id:                   th-orphans-0.13.17-LjnPD2PWHME9tnFdw8Hbhl
key:                  th-orphans-0.13.17-LjnPD2PWHME9tnFdw8Hbhl
license:              BSD-3-Clause
copyright:            (c) Matt Morrow, Michael Sloan, Ryan Scott
maintainer:           Ryan Scott <ryan.gl.scott@gmail.com>
author:               Matt Morrow, Michael Sloan, Ryan Scott
stability:            experimental
synopsis:             Orphan instances for TH datatypes
description:
    Orphan instances for TH datatypes.  In particular, instances
    for Ord and Lift, as well as a few missing Show / Eq.  These
    instances used to live in haskell-src-meta, and that'\''s where
    the version number started.

category:             Template Haskell
abi:                  dae76b0c6bce6dfcb7fe1661a64e3dac
exposed:              True
exposed-modules:      Language.Haskell.TH.Instances
hidden-modules:       Language.Haskell.TH.Instances.Internal
import-dirs:          /usr/lib/ghc-9.6.6/site-local/th-orphans-0.13.17
library-dirs:         /usr/lib/ghc-9.6.6/site-local/th-orphans-0.13.17
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/th-orphans-0.13.17
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-th-orphans
hs-libraries:         HSth-orphans-0.13.17-LjnPD2PWHME9tnFdw8Hbhl
depends:
    base-4.18.2.1 mtl-2.3.1 template-haskell-2.20.0.0
    th-compat-0.1.7-KgbHc432pdy6u5eqfJHAdS
    th-lift-0.8.7-JMijAGUD56uaCh66C6Lgg
    th-reify-many-0.1.10-AMdvWj5R0b3AKUNtZRTsge

haddock-interfaces:   /usr/share/doc/haskell-th-orphans/html/th-orphans.haddock
haddock-html:         /usr/share/doc/haskell-th-orphans/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

